@@ -1,7 +1,7 @@
 """
-Module: 'socket' on micropython-v1.17-pyboard
+Module: 'socket' on micropython-v1.18-pyboard
 """
-# MCU: {'ver': 'v1.17', 'port': 'pyboard', 'arch': 'armv7emsp', 'sysname': 'pyboard', 'release': '1.17.0', 'name': 'micropython', 'mpy': 7685, 'version': '1.17.0', 'machine': 'PYBv1.1 with STM32F405RG', 'build': '', 'nodename': 'pyboard', 'platform': 'pyboard', 'family': 'micropython'}
+# MCU: {'ver': 'v1.18', 'port': 'pyboard', 'arch': 'armv7emsp', 'sysname': 'pyboard', 'release': '1.18.0', 'name': 'micropython', 'mpy': 7685, 'version': '1.18.0', 'machine': 'PYBv1.1 with STM32F405RG', 'build': '', 'nodename': 'pyboard', 'platform': 'pyboard', 'family': 'micropython'}
 # Stubber: 1.5.4
 from typing import Any
 
@@ -26,9 +26,21 @@ class socket:
     def close(self, *args, **kwargs) -> Any:
         ...
 
+    def read(self, *args, **kwargs) -> Any:
+        ...
+
+    def readinto(self, *args, **kwargs) -> Any:
+        ...
+
+    def readline(self, *args, **kwargs) -> Any:
+        ...
+
     def send(self, *args, **kwargs) -> Any:
         ...
 
+    def write(self, *args, **kwargs) -> Any:
+        ...
+
     def accept(self, *args, **kwargs) -> Any:
         ...
 
